@@ -4,16 +4,7 @@ import re
 class Abbreviation():
 
     def __init__(self):
-        self.abbreviation_normalizer = AbbreviationNormalizer()
 
-    def normalize(self, doc_string):
-        normalized_string = self.abbreviation_normalizer.find_abbreviation_part(text_line=doc_string)
-
-        return normalized_string
-
-
-class AbbreviationNormalizer():
-    def __init__(self):
         self.abbreviation_rules = r'( ه ق )|( ه ش )|( ه.ق )|( ه.ش )|( ع )|( ره )|(\(ه ش\))|(\(ه ق\))|(\(ه.ش\))|(\(ه.ق\))|(\(ره\))|(\(ع\))|( ه ق )|( ه ش )|( ه.ق. )|( ه.ش. )|( ره )|(\(ه ش\))|(\(ه ق\))|(\(.ه.ش\))|(\(ه.ق.\))|(\(ره\))|(\(ع\))'
         self.abbreviation_dictionary = {
             'هق': ' هجری قمری ',
@@ -22,6 +13,11 @@ class AbbreviationNormalizer():
             'ع': ' علیه السلام '
         }
 
+    def normalize(self, doc_string):
+        normalized_string = self.find_abbreviation_part(text_line=doc_string)
+
+        return normalized_string
+
     def find_abbreviation_part(self, text_line):
         content_new = re.sub(self.abbreviation_rules, lambda x: self.abbreviation_converter(x.group()), " "+text_line+" ")
 
