@@ -371,18 +371,20 @@ class Normalizer():
 
 class Spacenormalizer():
     def __init__(self):
-        self.stemmer = mofid_normalizer.stemmer.FindStems()
+        pass
+        # self.stemmer = mofid_normalizer.stemmer.FindStems()
 
     def convert_space(self, text_line):
-        text_line_list = text_line.split()
-
-        text = ' '
-        for word in text_line_list:
-            result = self.stemmer.convert_to_stem(word)
-            text += result + ' '
-
-        text = re.sub(' +', ' ', text)
-        return "".join(text.rstrip().lstrip())
+        pass
+        # text_line_list = text_line.split()
+        #
+        # text = ' '
+        # for word in text_line_list:
+        #     result = self.stemmer.convert_to_stem(word)
+        #     text += result + ' '
+        #
+        # text = re.sub(' +', ' ', text)
+        # return "".join(text.rstrip().lstrip())
 
 
 class Punctuation():
